Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(28)

Unified Diff: webkit/tools/test_shell/event_sending_controller.h

Issue 6261: This fixes http://code.google.com/p/chromium/issues/detail?id=3007, which is ... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 12 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/tools/test_shell/event_sending_controller.h
===================================================================
--- webkit/tools/test_shell/event_sending_controller.h (revision 2916)
+++ webkit/tools/test_shell/event_sending_controller.h (working copy)
@@ -71,10 +71,13 @@
static void DoMouseUp(const WebMouseEvent& e);
static void ReplaySavedEvents();
- // Helper to extract the optional arg from mouseDown() and mouseUp()
- static WebMouseEvent::Button GetButtonTypeFromSingleArg(
- const CppArgumentList& args);
+ // Helper to return the button type given a button code
+ static WebMouseEvent::Button GetButtonTypeFromButtonNumber(int button_code);
+ // Helper to extract the button number from the optional argument in
+ // mouseDown and mouseUp
+ static int GetButtonNumberFromSingleArg(const CppArgumentList& args);
+
// Returns true if the key_code passed in needs a shift key modifier to
// be passed into the generated event.
bool NeedsShiftModifer(wchar_t key_code);
@@ -87,6 +90,11 @@
// Currently pressed mouse button (Left/Right/Middle or None)
static WebMouseEvent::Button pressed_button_;
+
+ // The last button number passed to mouseDown and mouseUp.
+ // Used to determine whether the click count continues to
+ // increment or not.
+ static int last_button_number_;
};
#endif // WEBKIT_TOOLS_TEST_SHELL_EVENT_SENDING_CONTROLLER_H_
« no previous file with comments | « webkit/tools/layout_tests/test_lists/tests_fixable.txt ('k') | webkit/tools/test_shell/event_sending_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698